@@ -65,11 +65,19 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-ar",                   ".a",        N_("Ar (.a)"), 0 },
 	{ "application/x-ar",                   ".ar",       N_("Ar (.ar)"), 0 },
 	{ "application/x-arj",                  ".arj",      N_("Arj (.arj)"), 0 },
+	{ "application/x-brotli",               ".br",       N_("brotli (.br)"), 0 },
+	{ "application/x-brotli-compressed-tar", ".tar.br", N_("Tar compressed with brotli (.tar.br)"), 0 },
 	{ "application/x-bzip",                 ".bz2",      NULL, 0 },
 	{ "application/x-bzip-compressed-tar",  ".tar.bz2",  N_("Tar compressed with bzip2 (.tar.bz2)"), 0 },
 	{ "application/x-bzip1",                ".bz",       NULL, 0 },
 	{ "application/x-bzip1-compressed-tar", ".tar.bz",   N_("Tar compressed with bzip (.tar.bz)"), 0 },
 	{ "application/vnd.ms-cab-compressed",  ".cab",      N_("Cabinet (.cab)"), 0 },
+	{ "application/vnd.oasis.opendocument.presentation",          ".odp", N_("OpenDocument Presentation"), 0 },
+	{ "application/vnd.oasis.opendocument.spreadsheet",           ".ods", N_("OpenDocument Spreadsheet"), 0 },
+	{ "application/vnd.oasis.opendocument.text",                  ".odt", N_("OpenDocument Text"), 0 },
+	{ "application/vnd.oasis.opendocument.presentation-template", ".otp", N_("OpenDocument Presentation Template"), 0 },
+	{ "application/vnd.oasis.opendocument.spreadsheet-template",  ".ots", N_("OpenDocument Spreadsheet Template"), 0 },
+	{ "application/vnd.oasis.opendocument.text-template",         ".ott", N_("OpenDocument Text Template"), 0 },
 	{ "application/x-cbr",                  ".cbr",      N_("Rar Archived Comic Book (.cbr)"), 0 },
 	{ "application/x-cbz",                  ".cbz",      N_("Zip Archived Comic Book (.cbz)"), 0 },
 	{ "application/x-cd-image",             ".iso",      NULL, 0 },
@@ -113,6 +121,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".ar", "application/x-ar" },
 	{ ".arj", "application/x-arj" },
 	{ ".bin", "application/x-stuffit" },
+	{ ".br", "application/x-brotli" },
 	{ ".bz", "application/x-bzip" },
 	{ ".bz2", "application/x-bzip" },
 	{ ".cab", "application/vnd.ms-cab-compressed" },
@@ -131,12 +140,19 @@ FrExtensionType file_ext_type[] = {
 	{ ".lz", "application/x-lzip" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
+	{ ".odp", "application/vnd.oasis.opendocument.presentation" },
+	{ ".ods", "application/vnd.oasis.opendocument.spreadsheet" },
+	{ ".odt", "application/vnd.oasis.opendocument.text" },
+	{ ".otp", "application/vnd.oasis.opendocument.presentation-template" },
+	{ ".ots", "application/vnd.oasis.opendocument.spreadsheet-template" },
+	{ ".ott", "application/vnd.oasis.opendocument.text-template" },
 	{ ".rar", "application/x-rar" },
 	{ ".rpm", "application/x-rpm" },
 	{ ".rz", "application/x-rzip" },
 	{ ".sit", "application/x-stuffit" },
 	{ ".swm", "application/x-ms-wim" },
 	{ ".tar", "application/x-tar" },
+	{ ".tar.br", "application/x-brotli-compressed-tar" },
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
